import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { renameKeysFromSDKRequestToRESTRequest, renameKeysFromRESTResponseToSDKResponse, } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixFunctionsV1FunctionFormCurrentValue from './functions-v1-function-form-current-value-function-form-current-values.http.js';
/**
 * Retrieves FunctionFormCurrentValue by the provided function id
 * @param functionId - Function form current value id, matching the function id
 * @internal
 * @documentationMaturity preview
 * @requiredField functionId
 * @permissionId FUNCTIONS.FUNCTION_FORM_CURRENT_VALUE_READ
 * @returns The returned Function form current value
 * @fqn wix.functions.formcurrentvalues.v1.FunctionFormCurrentValues.GetFunctionFormCurrentValue
 */
export async function getFunctionFormCurrentValue(functionId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        functionId: functionId,
    });
    const reqOpts = ambassadorWixFunctionsV1FunctionFormCurrentValue.getFunctionFormCurrentValue(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data)
            ?.functionFormCurrentValue;
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { functionId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['functionId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
//# sourceMappingURL=functions-v1-function-form-current-value-function-form-current-values.universal.js.map